#!/usr/bin/python

from .uppercase import UpperCase
from .lowercase import LowerCase
from .nospaces import NoSpaces
from .savespaces import SaveSpaces
from .savecase import SaveCase

__all__ = [
    "UpperCase", "LowerCase", "NoSpaces", "SaveSpaces", "SaveCase",
]
